==> qtjambi-opengl-debuginfo-macos-6.6.1.jar: sources/QtJambiOpenGL/QOpenGLVersionStatus_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtOpenGL/qopenglversionfunctions.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QOpenGLVersionStatus(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QOpenGLVersionStatus")
    QOpenGLVersionStatus *_ptr = reinterpret_cast<QOpenGLVersionStatus *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QOpenGLVersionStatus()
void __qt_construct_QOpenGLVersionStatus_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QOpenGLVersionStatus()")
    Q_UNUSED(__java_arguments)
    QOpenGLVersionStatus *__qt_this = new(__qtjambi_ptr) QOpenGLVersionStatus();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QOpenGLVersionStatus(int,int,QOpenGLVersionStatus::OpenGLStatus)
void __qt_construct_QOpenGLVersionStatus_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QOpenGLVersionStatus(int,int,QOpenGLVersionStatus::OpenGLStatus)")
    jint majorVersion0 = __java_arguments[0].i;
    Q_UNUSED(majorVersion0)
    jint minorVersion1 = __java_arguments[1].i;
    Q_UNUSED(minorVersion1)
    jobject functionStatus2 = __java_arguments[2].l;
    QOpenGLVersionStatus::OpenGLStatus __qt_functionStatus2 = qtjambi_cast<QOpenGLVersionStatus::OpenGLStatus>(__jni_env, functionStatus2);
    QOpenGLVersionStatus *__qt_this = new(__qtjambi_ptr) QOpenGLVersionStatus(static_cast<int>(majorVersion0), static_cast<int>(minorVersion1), QOpenGLVersionStatus::OpenGLStatus(__qt_functionStatus2));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QOpenGLVersionStatus
void __qt_destruct_QOpenGLVersionStatus(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QOpenGLVersionStatus")
    reinterpret_cast<QOpenGLVersionStatus*>(ptr)->~QOpenGLVersionStatus();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QOpenGLVersionStatus::QOpenGLVersionStatus()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_opengl_QOpenGLVersionStatus_initialize_1native__Lio_qt_opengl_QOpenGLVersionStatus_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QOpenGLVersionStatus::QOpenGLVersionStatus()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QOpenGLVersionStatus_0, sizeof(QOpenGLVersionStatus), typeid(QOpenGLVersionStatus), false, &deleter_QOpenGLVersionStatus, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QOpenGLVersionStatus::QOpenGLVersionStatus(int,int,QOpenGLVersionStatus::OpenGLStatus)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_opengl_QOpenGLVersionStatus_initialize_1native__Lio_qt_opengl_QOpenGLVersionStatus_2IILio_qt_opengl_QOpenGLVersionStatus_00024OpenGLStatus_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jint majorVersion0,
 jint minorVersion1,
 jobject functionStatus2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QOpenGLVersionStatus::QOpenGLVersionStatus(int,int,QOpenGLVersionStatus::OpenGLStatus)")
    QTJAMBI_TRY {
        jvalue arguments[3];
        arguments[0].i = majorVersion0;
        arguments[1].i = minorVersion1;
        arguments[2].l = functionStatus2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QOpenGLVersionStatus_1, sizeof(QOpenGLVersionStatus), typeid(QOpenGLVersionStatus), false, &deleter_QOpenGLVersionStatus, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QOpenGLVersionStatus::operator==(QOpenGLVersionStatus,QOpenGLVersionStatus)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_opengl_QOpenGLVersionStatus_equals_1native_1cref_1QOpenGLVersionStatus__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QOpenGLVersionStatus *__qt_this = QtJambiAPI::objectFromNativeId<QOpenGLVersionStatus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QOpenGLVersionStatus::operator==(QOpenGLVersionStatus,QOpenGLVersionStatus)", __qt_this)
        const QOpenGLVersionStatus& __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QOpenGLVersionStatus>(rhs1);
        __java_return_value = (*__qt_this) == __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_opengl_QOpenGLVersionStatus_setStatus_1native_1cref_1QOpenGLVersionStatus_1OpenGLStatus__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint status0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QOpenGLVersionStatus *__qt_this = QtJambiAPI::objectFromNativeId<QOpenGLVersionStatus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QOpenGLVersionStatus::OpenGLStatus __qt_status0 = qtjambi_cast<QOpenGLVersionStatus::OpenGLStatus>(__jni_env, status0);
        __qt_this->status = QOpenGLVersionStatus::OpenGLStatus(__qt_status0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_opengl_QOpenGLVersionStatus_status_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QOpenGLVersionStatus *__qt_this = QtJambiAPI::objectFromNativeId<QOpenGLVersionStatus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QOpenGLVersionStatus::OpenGLStatus&  __qt_value = __qt_this->status;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_opengl_QOpenGLVersionStatus_setVersion_1native_1cref_1QPair__JLio_qt_core_QPair_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject version0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QOpenGLVersionStatus *__qt_this = QtJambiAPI::objectFromNativeId<QOpenGLVersionStatus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QPair<int, int>&  __qt_version0 = qtjambi_cast<QPair<int, int> >(__jni_env, __qtjambi_scope, version0);
        __qt_this->version = __qt_version0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_opengl_QOpenGLVersionStatus_version_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QOpenGLVersionStatus *__qt_this = QtJambiAPI::objectFromNativeId<QOpenGLVersionStatus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QPair<int, int>&  __qt_value = __qt_this->version;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_opengl_QOpenGLVersionStatus_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QOpenGLVersionStatus *__qt_this = QtJambiAPI::objectFromNativeId<QOpenGLVersionStatus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_opengl_QOpenGLVersionStatus_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QOpenGLVersionStatus *__qt_this = QtJambiAPI::objectFromNativeId<QOpenGLVersionStatus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QOpenGLVersionStatus(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QOpenGLVersionStatus>("QOpenGLVersionStatus", "io/qt/opengl/QOpenGLVersionStatus");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QOpenGLVersionStatus, {
        ConstructorInfo(&__qt_construct_QOpenGLVersionStatus_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QOpenGLVersionStatus_1, "IILio/qt/opengl/QOpenGLVersionStatus$OpenGLStatus;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QOpenGLVersionStatus);
    registerMetaType<QOpenGLVersionStatus>("QOpenGLVersionStatus");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QOpenGLVersionStatus::OpenGLStatus>("QOpenGLVersionStatus::OpenGLStatus", "io/qt/opengl/QOpenGLVersionStatus$OpenGLStatus");
// END: enums and flags
}

==> qtjambi-opengl-debuginfo-macos-6.8.4.jar: sources/QtJambiOpenGL/QOpenGLVersionStatus_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtOpenGL/qopenglversionfunctions.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QOpenGLVersionStatus(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QOpenGLVersionStatus")
    QOpenGLVersionStatus *_ptr = reinterpret_cast<QOpenGLVersionStatus *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QOpenGLVersionStatus()
void __qt_construct_QOpenGLVersionStatus(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QOpenGLVersionStatus()")
    Q_UNUSED(__java_arguments)
    QOpenGLVersionStatus *__qt_this = new(__qtjambi_ptr) QOpenGLVersionStatus();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QOpenGLVersionStatus::QOpenGLVersionStatus()
extern "C" JNIEXPORT void JNICALL Java_io_qt_opengl_QOpenGLVersionStatus_initialize_1native__Lio_qt_opengl_QOpenGLVersionStatus_2
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QOpenGLVersionStatus::QOpenGLVersionStatus()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QOpenGLVersionStatus, sizeof(QOpenGLVersionStatus), typeid(QOpenGLVersionStatus), 0, false, &deleter_QOpenGLVersionStatus, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QOpenGLVersionStatus(QOpenGLVersionStatus)
void __qt_construct_QOpenGLVersionStatus_cref_QOpenGLVersionStatus(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QOpenGLVersionStatus(QOpenGLVersionStatus)")
    jobject other0 = __java_arguments[0].l;
    const QOpenGLVersionStatus& __qt_other0 = qtjambi_cast<const QOpenGLVersionStatus&>(__jni_env, other0);
    QOpenGLVersionStatus *__qt_this = new(__qtjambi_ptr) QOpenGLVersionStatus(__qt_other0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QOpenGLVersionStatus::QOpenGLVersionStatus(QOpenGLVersionStatus)
extern "C" JNIEXPORT void JNICALL Java_io_qt_opengl_QOpenGLVersionStatus_initialize_1native__Lio_qt_opengl_QOpenGLVersionStatus_2Lio_qt_opengl_QOpenGLVersionStatus_2
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QOpenGLVersionStatus::QOpenGLVersionStatus(QOpenGLVersionStatus)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QOpenGLVersionStatus_cref_QOpenGLVersionStatus, sizeof(QOpenGLVersionStatus), typeid(QOpenGLVersionStatus), 0, false, &deleter_QOpenGLVersionStatus, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QOpenGLVersionStatus(int,int,QOpenGLVersionStatus::OpenGLStatus)
void __qt_construct_QOpenGLVersionStatus_int_int_QOpenGLVersionStatus_OpenGLStatus(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QOpenGLVersionStatus(int,int,QOpenGLVersionStatus::OpenGLStatus)")
    jint majorVersion0 = __java_arguments[0].i;
    Q_UNUSED(majorVersion0)
    jint minorVersion1 = __java_arguments[1].i;
    Q_UNUSED(minorVersion1)
    jobject functionStatus2 = __java_arguments[2].l;
    QOpenGLVersionStatus::OpenGLStatus __qt_functionStatus2 = qtjambi_cast<QOpenGLVersionStatus::OpenGLStatus>(__jni_env, functionStatus2);
    QOpenGLVersionStatus *__qt_this = new(__qtjambi_ptr) QOpenGLVersionStatus(static_cast<int>(majorVersion0), static_cast<int>(minorVersion1), QOpenGLVersionStatus::OpenGLStatus(__qt_functionStatus2));
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QOpenGLVersionStatus::QOpenGLVersionStatus(int,int,QOpenGLVersionStatus::OpenGLStatus)
extern "C" JNIEXPORT void JNICALL Java_io_qt_opengl_QOpenGLVersionStatus_initialize_1native__Lio_qt_opengl_QOpenGLVersionStatus_2IILio_qt_opengl_QOpenGLVersionStatus_00024OpenGLStatus_2
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jint majorVersion0,
 jint minorVersion1,
 jobject functionStatus2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QOpenGLVersionStatus::QOpenGLVersionStatus(int,int,QOpenGLVersionStatus::OpenGLStatus)")
    QTJAMBI_TRY {
        jvalue arguments[3];
        arguments[0].i = majorVersion0;
        arguments[1].i = minorVersion1;
        arguments[2].l = functionStatus2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QOpenGLVersionStatus_int_int_QOpenGLVersionStatus_OpenGLStatus, sizeof(QOpenGLVersionStatus), typeid(QOpenGLVersionStatus), 0, false, &deleter_QOpenGLVersionStatus, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QOpenGLVersionStatus
void __qt_destruct_QOpenGLVersionStatus(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QOpenGLVersionStatus")
    reinterpret_cast<QOpenGLVersionStatus*>(ptr)->~QOpenGLVersionStatus();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QOpenGLVersionStatus::operator==(QOpenGLVersionStatus,QOpenGLVersionStatus)
extern "C" JNIEXPORT jboolean JNICALL Java_io_qt_opengl_QOpenGLVersionStatus_equals_1native_1cref_1QOpenGLVersionStatus__JJ
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QOpenGLVersionStatus *__qt_this = QtJambiAPI::objectFromNativeId<QOpenGLVersionStatus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QOpenGLVersionStatus::operator==(QOpenGLVersionStatus,QOpenGLVersionStatus)", __this_nativeId)
        const QOpenGLVersionStatus& __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QOpenGLVersionStatus>(rhs1);
        __java_return_value = (*__qt_this) == __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" JNIEXPORT void JNICALL Java_io_qt_opengl_QOpenGLVersionStatus_setStatus_1native_1cref_1QOpenGLVersionStatus_1OpenGLStatus__JI
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint status0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QOpenGLVersionStatus *__qt_this = QtJambiAPI::objectFromNativeId<QOpenGLVersionStatus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QOpenGLVersionStatus::OpenGLStatus __qt_status0 = qtjambi_cast<QOpenGLVersionStatus::OpenGLStatus>(__jni_env, status0);
        __qt_this->status = QOpenGLVersionStatus::OpenGLStatus(__qt_status0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" JNIEXPORT jint JNICALL Java_io_qt_opengl_QOpenGLVersionStatus_status_1native__J
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QOpenGLVersionStatus *__qt_this = QtJambiAPI::objectFromNativeId<QOpenGLVersionStatus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QOpenGLVersionStatus::OpenGLStatus&  __qt_value = __qt_this->status;
        __java_return_value = __qt_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" JNIEXPORT void JNICALL Java_io_qt_opengl_QOpenGLVersionStatus_setVersion_1native_1cref_1QPair__JLio_qt_core_QPair_2
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jobject version0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QOpenGLVersionStatus *__qt_this = QtJambiAPI::objectFromNativeId<QOpenGLVersionStatus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QPair<int, int>& __qt_version0 = qtjambi_cast<QPair<int, int> >(__jni_env, __qtjambi_scope, version0);
        __qt_this->version = __qt_version0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" JNIEXPORT jobject JNICALL Java_io_qt_opengl_QOpenGLVersionStatus_version_1native__J
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QOpenGLVersionStatus *__qt_this = QtJambiAPI::objectFromNativeId<QOpenGLVersionStatus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QPair<int, int>&  __qt_value = __qt_this->version;
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" JNIEXPORT jint JNICALL Java_io_qt_opengl_QOpenGLVersionStatus_hashCode_1native
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QOpenGLVersionStatus *__qt_this = QtJambiAPI::objectFromNativeId<QOpenGLVersionStatus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" JNIEXPORT jobject JNICALL Java_io_qt_opengl_QOpenGLVersionStatus_clone_1native
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QOpenGLVersionStatus *__qt_this = QtJambiAPI::objectFromNativeId<QOpenGLVersionStatus>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QOpenGLVersionStatus(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QOpenGLVersionStatus>("QOpenGLVersionStatus", "io/qt/opengl/QOpenGLVersionStatus");
    Q_UNUSED(typeId)
    registerConstructorInfos(typeId, 0, &__qt_destruct_QOpenGLVersionStatus, {
        ConstructorInfo{&__qt_construct_QOpenGLVersionStatus, nullptr}
       ,ConstructorInfo{&__qt_construct_QOpenGLVersionStatus_cref_QOpenGLVersionStatus, "Lio/qt/opengl/QOpenGLVersionStatus;"}
       ,ConstructorInfo{&__qt_construct_QOpenGLVersionStatus_int_int_QOpenGLVersionStatus_OpenGLStatus, "IILio/qt/opengl/QOpenGLVersionStatus$OpenGLStatus;"}
    });
    registerDeleter(typeId, &deleter_QOpenGLVersionStatus);
    registerMetaType<QOpenGLVersionStatus>("QOpenGLVersionStatus");
    registerEnumTypeInfo<QOpenGLVersionStatus::OpenGLStatus>("QOpenGLVersionStatus::OpenGLStatus", "io/qt/opengl/QOpenGLVersionStatus$OpenGLStatus");
}
